#
# spec file for package ghc-servant-client
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name servant-client
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.20
Release:        bp156.1.1
Summary:        Automatic derivation of querying functions for servant
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/3.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-media-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-kan-extensions-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroupoids-devel
BuildRequires:  ghc-servant-client-core-devel
BuildRequires:  ghc-servant-devel
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-entropy-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-http-api-data-devel
BuildRequires:  ghc-markdown-unlit-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-servant-server-devel
BuildRequires:  ghc-sop-core-devel
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-warp-devel
%endif

%description
This library lets you derive automatically Haskell functions that let you query
each endpoint of a <http://hackage.haskell.org/package/servant servant>
webservice.

See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section
of the tutorial>.

<https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md
CHANGELOG>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Mon Nov 27 2023 Peter Simons <psimons@suse.com>
- Update servant-client to version 0.20 revision 3.
  0.20
  - ---
  - Escape special chars in QueryParams. [#1584](https://github.com/haskell-servant/servant/issues/1584) [#1597](https://github.com/haskell-servant/servant/pull/1597)
    Escape special chars in QueryParam (`:@&=+$`) in servant-client. Note that this
    mean binary data will not work as is, and so reverts the functionality in
    [#1432](https://github.com/haskell-servant/servant/pull/1432).
  - Handle Cookies correctly for RunStreamingClient [#1605](https://github.com/haskell-servant/servant/issues/1605) [#1606](https://github.com/haskell-servant/servant/pull/1606)
    Makes `performWithStreamingRequest` take into consideration the
    CookieJar, which it previously didn't.
  - Fix the handling of multiple headers with the same name. [#1666](https://github.com/haskell-servant/servant/pull/1666)
    servant-client no longer concatenates the values of response headers with the same name.
    This fixes an issue with parsing multiple `Set-Cookie` headers.
* Thu Jun 22 2023 Peter Simons <psimons@suse.com>
- Update servant-client to version 0.19 revision 6.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Feb  2 2022 Peter Simons <psimons@suse.com>
- Update servant-client to version 0.19.
  Package versions follow the [Package Versioning Policy](https://pvp.haskell.org/): in A.B.C, bumps to either A or B represent major versions.
  0.19
  - ---
  [#]## Significant changes
  - Drop support for GHC < 8.6.
  - Support GHC 9.0 (GHC 9.2 should work as well, but isn't fully tested yet).
  - Support Aeson 2 ([#1475](https://github.com/haskell-servant/servant/pull/1475)),
    which fixes a [DOS vulnerability](https://github.com/haskell/aeson/issues/864)
    related to hash collisions.
  - Add `NamedRoutes` combinator, making support for records first-class in Servant
    ([#1388](https://github.com/haskell-servant/servant/pull/1388)).
  - Add custom type errors for partially applied combinators
    ([#1289](https://github.com/haskell-servant/servant/pull/1289),
    [#1486](https://github.com/haskell-servant/servant/pull/1486)).
  - *servant-client* / *servant-client-core* / *servant-http-streams*: Fix
    erroneous behavior, where only 2XX status codes would be considered
    successful, irrelevant of the status parameter specified by the verb
    combinator. ([#1469](https://github.com/haskell-servant/servant/pull/1469))
  - *servant-client* / *servant-client-core*: Fix `Show` instance for
    `Servant.Client.Core.Request`.
  - *servant-client* /  *servant-client-core*: Allow passing arbitrary binary data
    in Query parameters.
    ([#1432](https://github.com/haskell-servant/servant/pull/1432)).
  [#]## Other changes
  - Various version bumps.
* Tue Sep  7 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax constraints on base-compat
* Tue Aug 17 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax constraints on transformers-compat
* Fri Jun 25 2021 psimons@suse.com
- Update servant-client to version 0.18.3.
  0.18.3
  - -----
  [#]## Significant changes
  - Add response header support to UVerb (#1420)
  [#]## Other changes
  - Support GHC-9.0.1.
  - Bump `bytestring`, `hspec`, `http-client` and `QuickCheck` dependencies.
* Sat May 15 2021 psimons@suse.com
- Update servant-client to version 0.18.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Dec  9 2020 psimons@suse.com
- Add servant-client at version 0.18.2.
